@@ -29,6 +29,7 @@ from . import slogconf
 from .util import (
   Entry, Entries, KeyManager, RawResult, Result, VersData,
   FunctionWorker, GetVersionError,
+  FileLoadError,
 )
 from . import __version__
 from .sortversion import sort_version_keys
@@ -132,7 +133,12 @@ def read_verfile(file: Path) -> VersData:
   return v
 
 def write_verfile(file: Path, versions: VersData) -> None:
-  data = json.dumps(versions, ensure_ascii=False) + '\n'
+  # sort and indent to make it friendly to human and git
+  data = json.dumps(
+    dict(sorted(versions.items())),
+    indent=2,
+    ensure_ascii=False,
+  ) + '\n'
   safe_overwrite(str(file), data)
 
 class Options(NamedTuple):
@@ -144,22 +150,14 @@ class Options(NamedTuple):
   httplib: Optional[str]
   http_timeout: int
 
-class FileLoadError(Exception):
-  def __init__(self, kind, exc):
-    self.kind = kind
-    self.exc = exc
-
-  def __str__(self):
-    return f'failed to load {self.kind}: {self.exc}'
-
 def load_file(
   file: str, *,
   use_keymanager: bool,
 ) -> Tuple[Entries, Options]:
   try:
     config = toml.load(file)
-  except OSError as e:
-    raise FileLoadError('version configuration file', e)
+  except (OSError, toml.TomlDecodeError) as e:
+    raise FileLoadError('version configuration file', file, e)
 
   ver_files: Optional[Tuple[Path, Path]] = None
   keymanager = KeyManager(None)
@@ -184,10 +182,7 @@ def load_file(
         keyfile_s = os.path.expandvars(
           os.path.expanduser(c.get('keyfile')))
         keyfile = d / keyfile_s
-      try:
-        keymanager = KeyManager(keyfile)
-      except OSError as e:
-        raise FileLoadError('keyfile', e)
+      keymanager = KeyManager(keyfile)
 
     if 'source' in c:
       source_configs = c['source']
